@@ -26,7 +26,7 @@ from http.server import BaseHTTPRequestHandler, HTTPServer
 from .types import TypesActions
 from .HttpResponse import HttpResponse
 import redis
-from Crypto.Hash import SHA256
+import hashlib
 
 if os.environ.get('KAFKA', None):
     from .ms_base import KafkaBase as BaseClass
@@ -183,11 +183,10 @@ class Microservices(BaseClass, ABC):
         if os.environ.get('REDISVALIDATE', None) is None:
             return False
         else:
-            h = SHA256.new()
-            h.update(bytes(data, 'utf-8'))
-            response_redis = self.redisclient.getset(h.hexdigest(), data)
+            shahex = hashlib.sha224(bytes(data, 'utf-8')).hexdigest()
+            response_redis = self.redisclient.getset(shahex, data)
             if response_redis is None:
-                self.redisclient.expire(h.hexdigest(), (10 * 60))
+                self.redisclient.expire(shahex, (10 * 60))
                 return False
             return True
 
